==> homebank_5.2.7.orig.tar.gz: homebank-5.2.7/src/hb-tag.h <==
/*  HomeBank -- Free, easy, personal accounting for everyone.
 *  Copyright (C) 1995-2019 Maxime DOYEN
 *
 *  This file is part of HomeBank.
 *
 *  HomeBank is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  HomeBank is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __HB_TAG_H__
#define __HB_TAG_H__


typedef struct _tag		Tag;

struct _tag
{
	guint32   	key;
	gchar   	*name;

	/* unsaved datas */
	//gboolean	flt_select;
	guint		usage_count;
};


void da_tag_free(Tag *item);
Tag *da_tag_malloc(void);

void da_tag_destroy(void);
void da_tag_new(void);

guint		da_tag_length(void);
gboolean	da_tag_create_none(void);
gboolean	da_tag_remove(guint32 key);
gboolean	da_tag_insert(Tag *acc);
gboolean	da_tag_append(Tag *acc);
guint32		da_tag_get_max_key(void);
Tag		*da_tag_get_by_name(gchar *name);
Tag		*da_tag_get(guint32 key);

guint tags_count(guint32 *tags);
guint32 *tags_clone(guint32 *tags);
guint32 *tags_parse(const gchar *tagstring);
gchar *tags_tostring(guint32 *tags);

gboolean tag_rename(Tag *item, const gchar *newname);

GList *tag_glist_sorted(gint column);

#endif

==> homebank_5.3.2.orig.tar.gz: homebank-5.3.2/src/hb-tag.h <==
/*  HomeBank -- Free, easy, personal accounting for everyone.
 *  Copyright (C) 1995-2020 Maxime DOYEN
 *
 *  This file is part of HomeBank.
 *
 *  HomeBank is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  HomeBank is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __HB_TAG_H__
#define __HB_TAG_H__


typedef struct _tag		Tag;

struct _tag
{
	guint32   	key;
	gchar   	*name;

	/* unsaved datas */
	//gboolean	flt_select;
	guint		usage_count;
};


void da_tag_free(Tag *item);
Tag *da_tag_malloc(void);

void da_tag_destroy(void);
void da_tag_new(void);

guint		da_tag_length(void);
gboolean	da_tag_create_none(void);
gboolean	da_tag_delete(guint32 key);
gboolean	da_tag_insert(Tag *acc);
gboolean	da_tag_append(Tag *acc);
guint32		da_tag_get_max_key(void);
Tag		*da_tag_get_by_name(gchar *name);
Tag		*da_tag_get(guint32 key);

guint tags_count(guint32 *tags);
guint32 *tags_clone(guint32 *tags);
guint32 *tags_parse(const gchar *tagstring);
gchar *tags_tostring(guint32 *tags);

gboolean tag_rename(Tag *item, const gchar *newname);

GList *tag_glist_sorted(gint column);

#endif
